Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-01-23 03:45:39 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-01-23 03:45:39 +0300
commitfc1fd2704a7b1cc448b20ed5cb596784cb764224 (patch)
tree2b24db79955d2ac49e0d45d269cec0917a387cdc /intern/cycles/device/device.h
parent367e61117907bb7507935251ecb7e396a4c91cbc (diff)
parentbf7e4067663cec0a3b4d3194e89a28aa62b39773 (diff)
Merge branch 'master' into blender2.8
Diffstat (limited to 'intern/cycles/device/device.h')
-rw-r--r--intern/cycles/device/device.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/intern/cycles/device/device.h b/intern/cycles/device/device.h
index d6ae01d28be..721898458fc 100644
--- a/intern/cycles/device/device.h
+++ b/intern/cycles/device/device.h
@@ -19,6 +19,8 @@
#include <stdlib.h>
+#include "bvh/bvh_params.h"
+
#include "device/device_memory.h"
#include "device/device_task.h"
@@ -52,14 +54,14 @@ public:
string description;
string id; /* used for user preferences, should stay fixed with changing hardware config */
int num;
- bool display_device; /* GPU is used as a display device. */
- bool advanced_shading; /* Supports full shading system. */
- bool has_fermi_limits; /* Fixed number of textures limit. */
- bool has_half_images; /* Support half-float textures. */
- bool has_volume_decoupled; /* Decoupled volume shading. */
- bool has_qbvh; /* Supports both BVH2 and BVH4 raytracing. */
- bool has_osl; /* Support Open Shading Language. */
- bool use_split_kernel; /* Use split or mega kernel. */
+ bool display_device; /* GPU is used as a display device. */
+ bool advanced_shading; /* Supports full shading system. */
+ bool has_fermi_limits; /* Fixed number of textures limit. */
+ bool has_half_images; /* Support half-float textures. */
+ bool has_volume_decoupled; /* Decoupled volume shading. */
+ BVHLayoutMask bvh_layout_mask; /* Bitmask of supported BVH layouts. */
+ bool has_osl; /* Support Open Shading Language. */
+ bool use_split_kernel; /* Use split or mega kernel. */
int cpu_threads;
vector<DeviceInfo> multi_devices;
@@ -74,7 +76,7 @@ public:
has_fermi_limits = false;
has_half_images = false;
has_volume_decoupled = false;
- has_qbvh = false;
+ bvh_layout_mask = BVH_LAYOUT_NONE;
has_osl = false;
use_split_kernel = false;
}